==> verttice_ui-0.0.97.tar.gz: lib/src/widgets/data_factory/form_factory/password_form.dart <==
import 'package:verttice_logic/verttice_logic.dart';
import "package:verttice_ui/src/const/box_sizes.dart";
import "package:flutter/material.dart";
import "package:flutter_pw_validator/Utilities/Validator.dart";
import "package:flutter_pw_validator/flutter_pw_validator.dart";
import 'package:verttice_ui/src/widgets/border_label.dart';
import 'package:verttice_ui/src/widgets/themed_widgets/themed_widgets_index.dart';

class PasswordFormFactory extends StatefulWidget {
  final Function(String name, dynamic value) onChanged;
  final String displayName;
  final String name;
  final String? value;
  final FormFieldState<dynamic>? state;
  const PasswordFormFactory({
    Key? key,
    required this.onChanged,
    required this.displayName,
    required this.name,
    this.value,
    this.state,
  }) : super(key: key);

  @override
  _PasswordFormFactoryState createState() => _PasswordFormFactoryState();
}

class _PasswordFormFactoryState extends State<PasswordFormFactory> {
  String _value = "";
  final TextEditingController _passwordController = TextEditingController();

  @override
  void initState() {
    _value = DataClassUtils.dynamicToString(widget.value, defultValue: "");
    super.initState();
  }

  @override
  void didUpdateWidget(covariant PasswordFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = DataClassUtils.dynamicToString(widget.value, defultValue: "");
    }
  }

  bool _isPassowdValid(String pass) {
    if (Validator().hasMinLength(pass, 8) &&
        Validator().hasMinNumericChar(pass, 2) &&
        Validator().hasMinSpecialChar(pass, 1) &&
        Validator().hasMinUppercase(pass, 1)) {
      return true;
    }
    return false;
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      onPressed: () async {
        await showDialog(
            context: context,
            builder: (BuildContext context) => SimpleDialog(
                  contentPadding: const EdgeInsets.all(10),
                  title: const SelectableText("Password"),
                  children: [
                    TextField(
                      controller: _passwordController,
                      decoration: const InputDecoration(labelText: "Password"),
                      onChanged: (String val) {
                        if (_isPassowdValid(val)) {
                          widget.onChanged(widget.name, val);
                          widget.state?.didChange(val);
                        }
                      },
                    ),
                    sizedBoxH4,
                    FlutterPwValidator(
                      controller: _passwordController,
                      minLength: 8,
                      uppercaseCharCount: 1,
                      numericCharCount: 2,
                      specialCharCount: 1,
                      width: 400,
                      height: 150,
                      onSuccess: () {},
                    ),
                    const Divider(),
                    TextButton(
                      child: const Text(
                        "Finish",
                        style: TextStyle(color: Colors.red),
                      ),
                      onPressed: () async {
                        if (!_isPassowdValid(_value)) {
                          ThemedToast.warning(
                              context: context, message: "Password NOT valid");
                        }
                        return Navigator.of(context).pop(null);
                      },
                    ),
                  ],
                ));
      },
      child: const Text("Super secret password, click to set new"),
    );
  }
}

==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/data_factory/form_factory/password_form.dart <==
// 🐦 Flutter imports:
import "package:flutter/material.dart";

// 📦 Package imports:
import "package:flutter_pw_validator/Utilities/Validator.dart";
import "package:flutter_pw_validator/flutter_pw_validator.dart";
import 'package:verttice_logic/verttice_logic.dart';

// 🌎 Project imports:
import "package:verttice_ui/src/const/box_sizes.dart";
import 'package:verttice_ui/src/widgets/border_label.dart';
import 'package:verttice_ui/src/widgets/themed_widgets/themed_widgets_index.dart';

class PasswordFormFactory extends StatefulWidget {
  final Function(String name, dynamic value) onChanged;
  final String displayName;
  final String name;
  final String? value;
  final FormFieldState<dynamic>? state;
  final String? tip;

  const PasswordFormFactory({
    Key? key,
    required this.onChanged,
    required this.displayName,
    required this.name,
    this.value,
    this.state,
    this.tip,
  }) : super(key: key);

  @override
  State<PasswordFormFactory> createState() => _PasswordFormFactoryState();
}

class _PasswordFormFactoryState extends State<PasswordFormFactory> {
  String _value = "";
  final TextEditingController _passwordController = TextEditingController();

  @override
  void initState() {
    _value = DataClassUtils.dynamicToString(widget.value, defaultValue: "");
    super.initState();
  }

  @override
  void didUpdateWidget(covariant PasswordFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = DataClassUtils.dynamicToString(widget.value, defaultValue: "");
    }
  }

  bool _isPassowdValid(String pass) {
    if (Validator().hasMinLength(pass, 8) &&
        Validator().hasMinNumericChar(pass, 2) &&
        Validator().hasMinSpecialChar(pass, 1) &&
        Validator().hasMinUppercase(pass, 1)) {
      return true;
    }
    return false;
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      tip: widget.tip,
      onPressed: () async {
        await showDialog(
            context: context,
            builder: (BuildContext context) => SimpleDialog(
                  contentPadding: const EdgeInsets.all(10),
                  title: const SelectableText("Password"),
                  children: [
                    TextField(
                      controller: _passwordController,
                      decoration: const InputDecoration(labelText: "Password"),
                      onChanged: (String val) {
                        if (_isPassowdValid(val)) {
                          widget.onChanged(widget.name, val);
                          widget.state?.didChange(val);
                        }
                      },
                    ),
                    sizedBoxH4,
                    FlutterPwValidator(
                      controller: _passwordController,
                      minLength: 8,
                      uppercaseCharCount: 1,
                      numericCharCount: 2,
                      specialCharCount: 1,
                      width: 400,
                      height: 150,
                      onSuccess: () {},
                    ),
                    const Divider(),
                    TextButton(
                      child: const Text(
                        "Finish",
                        style: TextStyle(color: Colors.red),
                      ),
                      onPressed: () async {
                        if (!_isPassowdValid(_value)) {
                          ThemedToast.warning(
                              context: context, message: "Password NOT valid");
                        }
                        return Navigator.of(context).pop(null);
                      },
                    ),
                  ],
                ));
      },
      child: const Text("Super secret password, click to set new"),
    );
  }
}
